@@ -3,20 +3,19 @@
 __all__ = [
     'connect', 'get_client',
     'type_case',
-    'Dict', 'List', 'Set', 'SortedSet', 'SingleValue', 'Counter',
-    'Server',
+    'Dict', 'Set', 'SortedSet', 'String', 'Counter', 'Deque',
     '__version__',
 ]
 
-from client import connect, get_client
 import type_case
 
+from client import connect, get_client
+
 from mix.dict import Dict
-from mix.list import List
 from mix.set import Set
 from mix.sorted_set import SortedSet
-from mix.single_value import SingleValue, Counter
+from mix.string import String
+from mix.counter import Counter
+from mix.deque import Deque
 
-from server import Server
-
-__version__ = "1.4.1.2"
+__version__ = "1.9.0"
